@@ -1,5 +1,5 @@
 package App::Sky::Config::Validate;
-$App::Sky::Config::Validate::VERSION = '0.4.1';
+$App::Sky::Config::Validate::VERSION = '0.4.2';
 use strict;
 use warnings;
 
@@ -19,7 +19,9 @@ sub _sorted_keys
 {
     my $hash_ref = shift;
 
-    return sort { $a cmp $b } keys(%$hash_ref);
+    my @ret = sort { $a cmp $b } keys(%$hash_ref);
+
+    return @ret;
 }
 
 sub _validate_section
@@ -121,19 +123,11 @@ __END__
 
 =head1 NAME
 
-App::Sky::Config::Validate
-
-=head1 VERSION
-
-version 0.4.1
-
-=head1 NAME
-
 App::Sky::Config::Validate - validate the configuration.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 METHODS
 
@@ -146,7 +140,7 @@ The configuration to validate.
 Determines if the configuration is valid. Throws an exception if not valid,
 and returns FALSE (in both list context and scalar context if it is valid.).
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -167,14 +161,6 @@ L<https://metacpan.org/release/App-Sky>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Sky>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -183,22 +169,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Sky>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Sky>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Sky>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
