@@ -1,5 +1,5 @@
 package App::Sky::Exception;
-$App::Sky::Exception::VERSION = '0.4.1';
+$App::Sky::Exception::VERSION = '0.4.2';
 use strict;
 use warnings;
 
@@ -23,11 +23,11 @@ __END__
 
 =head1 NAME
 
-App::Sky::Exception
+App::Sky::Exception - provides various exception classes for App::Sky
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
@@ -37,14 +37,6 @@ version 0.4.1
 
 These are L<Exception:Class> exceptions for L<App::Sky> .
 
-=head1 NAME
-
-App::Sky::Exception - provides various exception classes for App::Sky
-
-=head1 VERSION
-
-version 0.4.1
-
 =head1 FUNCTIONS
 
 =head2 new($args)
@@ -59,7 +51,7 @@ Shlomi Fish, L<http://www.shlomifish.org/> .
 
 1; # End of App::Sky::Exception
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -80,14 +72,6 @@ L<https://metacpan.org/release/App-Sky>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Sky>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -96,22 +80,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Sky>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Sky>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Sky>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
