@@ -1,5 +1,5 @@
 package App::Sky::Results;
-$App::Sky::Results::VERSION = '0.4.1';
+$App::Sky::Results::VERSION = '0.4.2';
 use strict;
 use warnings;
 
@@ -25,19 +25,11 @@ __END__
 
 =head1 NAME
 
-App::Sky::Results
-
-=head1 VERSION
-
-version 0.4.1
-
-=head1 NAME
-
 App::Sky::Results - results of an upload.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 METHODS
 
@@ -49,7 +41,7 @@ The upload command to execute.
 
 An array reference of L<URI> objects where the files were uploaded to.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -70,14 +62,6 @@ L<https://metacpan.org/release/App-Sky>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Sky>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -86,22 +70,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Sky>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Sky>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Sky>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
